Crate kcode_session_log

Crate kcode_session_log 

kcode-session-log provides durable, append-ordered session history.

A session log stores one three-field header followed by ordered {role, text} events. Event positions are their stable identities and are not serialized. Pending objects are written to one self-contained file each before their corresponding events are appended.

Structs

EventPosition
PendingObject
SealedSession
Session
SessionEvent
SessionHeader
SessionLog
SessionStore

Enums

Role

Constants

FORMAT_VERSION